//
// Vectrex simple example by Sebastian Mihai
// 

#include <vectrex.h>

/* NON CONSTANT VARIABLES NOT ALLOWED TO BE INITIALIZED */

/*
 * Some defines, Maximal brightness is $7f, highest not set!
 * Max Scale would be $ff, well here we take only $f0!
 */
#define MAX_BRIGHTNESS (0x7f)

#define SCALE 120                  /* for positioning the dots on the screen */
#define DOT_BRIGHTNESS 5                /* dot dwell time... */

static inline void initialize() {
	enable_joystick_1x();
	enable_joystick_1y();
	disable_joystick_2x();
	disable_joystick_2y();
	joy_digital();
	read_buttons();
	wait_recal();
	read_buttons();
	wait_recal();
}

static inline void put_dot()
{
 write_ram(Vec_Dot_Dwell, DOT_BRIGHTNESS); /* first set up the dot dwell time */
 draw_dot( 0, 0 ); /* position and draw the dot */
}

static inline void line_to( char x, char y )
{
	write_ram(Vec_Dot_Dwell, DOT_BRIGHTNESS); /* first set up the dot dwell time */
	draw_line( x, y );
}
						   
int main(void)
{
  unsigned char i;
  signed char x, y;
  x = 0;y=0;
  initialize();
  
  while ( 1 )
  {
	//set_dp_c8();
    wait_recal();
    intensity(MAX_BRIGHTNESS);  /* set intensity of vector beam... */

	zero_beam();
	move_to(x, y);
	set_scale(SCALE);
	
	// draw a square made of dots
	for(i=0;i<5;i++) {
		move_to(1, 0);
		put_dot();
	}
	
	for(i=0;i<5;i++) {
		move_to(0, 1);
		put_dot();
	}
	
	for(i=0;i<5;i++) {
		move_to(-1, 0);
		put_dot();
	}
	
	for(i=0;i<5;i++) {
		move_to(0, -1);
		put_dot();
	}
	
	// draw first two lines at normal scale
	set_scale(SCALE);
	line_to( 30, 15 );
	line_to( -50, -50 );
	
	// move beam down
	move_to( 0, -20 );
	
	// draw second two lines at double scale
	set_scale(2*SCALE);
	line_to( 30, 15 );
	line_to( -50, -50 );
	
	// bring beam to centre again, and print messages
	zero_beam();
	print_str(-100,0,"SIMPLE EXAMPLE!");
	print_str(-120,40,"USE JOYSTICK");
	print_str(-120,20,"TO MOVE");

	// draw a triangle (beam is still at center)
	set_scale(SCALE);
	move_to( -50, 0 );
	line_to( 50, 50 );
	line_to( 50, -50 );
	line_to( -100, 0 );
	
	
	if(joystick1_x>0) {
		x++;
    } else if(joystick1_x<0) {
		x--;
    }
    
	if(joystick1_y>0) {
		y++;
    } else if(joystick1_y<0) {
		y--;
    }
	 
	joy_digital();
  }
}

